@@ -1,5 +1,5 @@
 """Bass shaker synthesizer for DCS World.
 
-Receives aircraft telemetry from `export.lua` over UDP and synthesizes, in
+Receives aircraft telemetry from `Export.lua` over UDP and synthesizes, in
 real-time, low frequency effect signals based on the telemetry values.
 """
